BarabasiAgingOptions

Struct BarabasiAgingOptions 

pub struct BarabasiAgingOptions<'a> {
    pub m: usize,
    pub outseq: Option<&'a [i64]>,
    pub outpref: bool,
    pub pa_exp: f64,
    pub aging_exp: f64,
    pub aging_bins: usize,
    pub zero_deg_appeal: f64,
    pub zero_age_appeal: f64,
    pub deg_coef: f64,
    pub age_coef: f64,
    pub directed: bool,
}
Options of Graph::barabasi_aging_game.

The attractiveness of a vertex with (in-)degree k and age l is (deg_coef * k^pa_exp + zero_deg_appeal) * (age_coef * l^aging_exp + zero_age_appeal). The defaults (those of R igraph’s sample_pa_age) describe linear preferential attachment without aging.

Fields

m: usize

Edges added per time step when outseq is None (default 1).

outseq: Option<&'a [i64]>

Edges added in each time step (overrides m). Default None.

outpref: bool

Whether edges initiated by a vertex count in its attractiveness (default false).

pa_exp: f64

Preferential attachment exponent (default 1).

aging_exp: f64

Aging exponent, usually negative (default 0, i.e. no aging).

aging_bins: usize

Number of age bins (default 300).

zero_deg_appeal: f64

Degree dependent attractiveness of zero-degree vertices (default 1).

zero_age_appeal: f64

Age dependent attractiveness of age-zero vertices (default 0).

deg_coef: f64

Coefficient of the degree term (default 1).

age_coef: f64

Coefficient of the age term (default 1).

directed: bool

Whether to create a directed graph (default true).