BarabasiOptions

Struct BarabasiOptions 

pub struct BarabasiOptions<'a> {
    pub power: f64,
    pub m: usize,
    pub outseq: Option<&'a [i64]>,
    pub outpref: bool,
    pub a: f64,
    pub directed: bool,
    pub algorithm: BarabasiAlgorithm,
    pub start_from: Option<&'a Graph>,
}
Options of Graph::barabasi_game, with the defaults of the classic undirected Barabási–Albert model (m = 1, power = 1, A = 1, BarabasiAlgorithm::Psumtree).

use igraph::prelude::*;
use igraph::games::BarabasiOptions;

let opts = BarabasiOptions::default().with_m(3).with_directed(true).with_power(0.5);
assert_eq!((opts.m, opts.directed, opts.power), (3, true, 0.5));

Fields

power: f64

Exponent of the preferential attachment: the probability of citing a vertex of degree d is proportional to d^power + a (default 1).

m: usize

Number of edges added with each new vertex, used when outseq is None (default 1).

outseq: Option<&'a [i64]>

Explicit number of edges added with each vertex (the first entry is ignored, as the first vertex cannot cite anybody). With start_from, it refers only to the newly added vertices. Default None.

outpref: bool

Whether the out-degree also counts in the attractiveness (i.e. total degree instead of in-degree). Ignored (assumed true) for undirected graphs. Default false.

a: f64

The constant attractiveness A of vertices (default 1).

directed: bool

Whether to create a directed graph (default false).

algorithm: BarabasiAlgorithm

The sampling algorithm (default BarabasiAlgorithm::Psumtree, that creates simple graphs).

start_from: Option<&'a Graph>

An optional non-empty starting graph; by default the process starts from a single vertex (the C documentation mentions a clique of size m, but the implementation starts from one vertex in igraph 1.0.0 and 1.0.1). The generated graph contains it as its first vertices and edges.

Implementations

Source

impl<'a> BarabasiOptions<'a>

pub fn with_power(self, power: f64) -> Self

Sets power.

pub fn with_m(self, m: usize) -> Self

Sets m.

pub fn with_outseq(self, outseq: &'a [i64]) -> Self

Sets outseq.

pub fn with_outpref(self, outpref: bool) -> Self

Sets outpref.

pub fn with_a(self, a: f64) -> Self

Sets the constant attractiveness a.

pub fn with_directed(self, directed: bool) -> Self

Sets directed.

pub fn with_algorithm(self, algorithm: BarabasiAlgorithm) -> Self

Sets algorithm.

pub fn with_start_from(self, start_from: &'a Graph) -> Self

Sets start_from.