pub struct RecentDegreeAgingOptions<'a> {
pub m: usize,
pub outseq: Option<&'a [i64]>,
pub outpref: bool,
pub pa_exp: f64,
pub aging_exp: f64,
pub aging_bins: usize,
pub window: usize,
pub zero_appeal: f64,
pub directed: bool,
}Expand description
Options of Graph::recent_degree_aging_game.
The attractiveness is (k^pa_exp + zero_appeal) * l^aging_exp, where k
is the number of edges gained in the last window steps and l the age.
Fields
m: usizeEdges added per time step when outseq is None (default 1).
outseq: Option<&'a [i64]>Edges added in each time step (overrides m). Default None.
outpref: boolWhether edges initiated by a vertex are counted (default false).
pa_exp: f64Preferential attachment exponent (default 1).
aging_exp: f64Aging exponent, usually negative (default 0, i.e. no aging).
aging_bins: usizeNumber of age bins (default 300).
window: usizeSize of the time window (default 1).
zero_appeal: f64Degree dependent attractiveness of vertices without recent edges
(default 1).
directed: boolWhether to create a directed graph (default false).