pub struct RecentDegreeOptions<'a> {
pub power: f64,
pub window: usize,
pub m: usize,
pub outseq: Option<&'a [i64]>,
pub outpref: bool,
pub zero_appeal: f64,
pub directed: bool,
}Expand description
Options of Graph::recent_degree_game.
The probability that a vertex is cited is proportional to
k^power + zero_appeal, where k is the number of edges it gained in the
last window time steps.
Fields
power: f64Exponent of the recent degree (default 1).
window: usizeSize of the time window (default 1).
m: usizeEdges added per time step when outseq is None (default 1).
outseq: Option<&'a [i64]>Edges added in each time step (overrides m). Default None.
outpref: boolWhether edges originated by a vertex also count as recent edges
(default false).
zero_appeal: f64Attractiveness of the vertices without recent edges (default 1).
directed: boolWhether to create a directed graph (default false).